function [varargout] = fl_ifsbdsynthesis_compute(varargin)
% Callback functions for ifsbdsynthesis GUI Environment.

% Author Christian Choque Cortez, October 2009

% FracLab 2.05 Beta, Copyright  1996 - 2009 by INRIA
% -- --
% For details on use and redistribution refer to $fraclab/licence.txt
%--------------------------------------------------------------------------

[objTmp,ifsbdsynthesis_fig] = gcbo;

if ((isempty(ifsbdsynthesis_fig)) || (~strcmp(get(ifsbdsynthesis_fig,'Tag'),'Fig_gui_fl_ifsbdsynthesis')))
    ifsbdsynthesis_fig = findobj ('Tag','Fig_gui_fl_ifsbdsynthesis');
end

fl_clearerror;
switch(varargin{1})
    case 'standard_option'
        if ~get(findobj(ifsbdsynthesis_fig,'Tag','RadioButton_standard'),'Value')
            set(findobj(ifsbdsynthesis_fig,'Tag','RadioButton_standard'),'Value',1);
        end
        set(findobj(ifsbdsynthesis_fig,'Tag','RadioButton_generalized'),'Value',0);
        set(findobj(ifsbdsynthesis_fig,'Tag','Checkbox_law'),'Style','checkbox','String','Affine interpolation','Enable','on','Value',0);
        set(findobj(ifsbdsynthesis_fig,'Tag','StaticText_interpoints2'),'String','[X1 Y1;X2 Y2;...;Xk Yk]');
        set(findobj(ifsbdsynthesis_fig,'Tag','StaticText_contraction1'),'String','Contraction coefs');
        set(findobj(ifsbdsynthesis_fig,'Tag','PopupMenu_exponent'),'Value',1,'Enable','off');
        set(findobj(ifsbdsynthesis_fig,'Tag','StaticText_contraction2'),'Enable','on');
        set(findobj(ifsbdsynthesis_fig,'Tag','EditText_contraction'),'String','[0.5;-0.9]');
        
    case 'generalized_option'
        if ~get(findobj(ifsbdsynthesis_fig,'Tag','RadioButton_generalized'),'Value')
            set(findobj(ifsbdsynthesis_fig,'Tag','RadioButton_generalized'),'Value',1);
        end
        set(findobj(ifsbdsynthesis_fig,'Tag','RadioButton_standard'),'Value',0);
        set(findobj(ifsbdsynthesis_fig,'Tag','Checkbox_law'),'Enable','off');
        set(findobj(ifsbdsynthesis_fig,'Tag','StaticText_interpoints2'),'String','[X1 Y1;X2 Y2;X3 Y3]');
        set(findobj(ifsbdsynthesis_fig,'Tag','EditText_point'),'String','[0 0;0.5 1;1 0]');
        set(findobj(ifsbdsynthesis_fig,'Tag','StaticText_contraction1'),'String','Holder function');
        set(findobj(ifsbdsynthesis_fig,'Tag','PopupMenu_exponent'),'Value',1,'Enable','on');
        set(findobj(ifsbdsynthesis_fig,'Tag','StaticText_contraction2'),'Enable','off');
        set(findobj(ifsbdsynthesis_fig,'Tag','EditText_contraction'),'String','0.2*(1-floor(2*t))+0.8*floor(2*t)');
        sample_value = 2^(get(findobj(ifsbdsynthesis_fig,'Tag','PopupMenu_sample'),'Value')+2);
        set(findobj(ifsbdsynthesis_fig,'Tag','EditText_sample'),'String',sample_value);
        
    case 'edit_interpoint'
        point = str2num(get(gcbo,'String'));  %#ok<ST2NM>
        Hldstandard = get(findobj(ifsbdsynthesis_fig,'Tag','RadioButton_standard'),'Value');
        if ~Hldstandard && length(point) ~= 3
            fl_warning('Generalized option require 3 interpolation points!'); pause(.3)
            point = [0 0;0.5 1;1 0];
        end
        if isempty(point) || comparevector(point)
            fl_warning('Interpolation points must be different [x,y] vectors!'); pause(.3)
            set(gcbo,'String','[0 0;0.5 1;1 0]');
            set(findobj(ifsbdsynthesis_fig,'Tag','EditText_contraction'),'String','[0.5;-0.9]');
        else
            point = sortrows(point); k =length(point);
            contraction = str2num(get(findobj(ifsbdsynthesis_fig,'Tag','EditText_contraction'),'String')); %#ok<ST2NM>
            if length(contraction) ~= length(point)
                contraction = round(10*rand(1,k-1)-5*ones(1,k-1))/5;
                set(findobj(ifsbdsynthesis_fig,'Tag','EditText_contraction'),'String',mat2str(contraction));
            end
            set(gcbo,'String',mat2str(point));
        end
    
    case 'popmenu_exponent'
        function_type = get(gcbo,'Value');
        switch function_type
            case 1
                set(findobj(ifsbdsynthesis_fig,'Tag','EditText_contraction'),'String','0.2*(1-floor(2*t))+0.8*floor(2*t)');
                set(findobj(ifsbdsynthesis_fig,'Tag','Button_close'),'enable','on');
                set(findobj(ifsbdsynthesis_fig,'Tag','Button_compute'),'enable','on');
            case 2
                set(findobj(ifsbdsynthesis_fig,'Tag','EditText_contraction'),'String','0.1+0.8*t');
                set(findobj(ifsbdsynthesis_fig,'Tag','Button_close'),'enable','on');
                set(findobj(ifsbdsynthesis_fig,'Tag','Button_compute'),'enable','on');
            case 3
                set(findobj(ifsbdsynthesis_fig,'Tag','EditText_contraction'),'String','abs(sin(3*pi*t))');
                set(findobj(ifsbdsynthesis_fig,'Tag','Button_close'),'enable','on');
                set(findobj(ifsbdsynthesis_fig,'Tag','Button_compute'),'enable','on');
            case 4
                set(findobj(ifsbdsynthesis_fig,'Tag','EditText_contraction'),'String','');
        end
        set(findobj(ifsbdsynthesis_fig,'Tag','Button_close'),'enable','on');
        set(findobj(ifsbdsynthesis_fig,'Tag','Button_compute'),'enable','on');
        
    case 'edit_contraction'
        Hldstandard = get(findobj(ifsbdsynthesis_fig,'Tag','RadioButton_standard'),'Value');
        if Hldstandard
            contraction = str2num(get(gcbo,'String'));  %#ok<ST2NM>
            k = length(str2num(get(findobj(ifsbdsynthesis_fig,'Tag','EditText_point'),'String'))); %#ok<ST2NM>
            if isempty(contraction)
                fl_warning('Contraction coefs muts be a [C1;C2;...Ck-1] vector!'); pause(.3)
                contraction = round(10*rand(1,k-1)-5*ones(1,k-1))/5;
                set(gcbo,'String',mat2str(contraction));
            else
                if length(contraction) ~= k-1
                    fl_warning('With k iterpolation points use k-1 coefficients!'); pause(.3)
                    contraction = round(10*rand(1,k-1)-5*ones(1,k-1))/5;
                    set(gcbo,'String',mat2str(contraction));
                else
                    set(gcbo,'String',mat2str(contraction));
                end
            end
        else
            function_value = get(gcbo,'String');
            N = str2double(get(findobj(ifsbdsynthesis_fig,'Tag','EditText_sample'),'String'));
            t = linspace(0,1,N); %#ok<NASGU>
            set(findobj(ifsbdsynthesis_fig,'Tag','PopupMenu_exponent'),'Value',4);
            try
                eval([function_value,';']);
                set(findobj(ifsbdsynthesis_fig,'Tag','Button_close'),'enable','on');
                set(findobj(ifsbdsynthesis_fig,'Tag','Button_compute'),'enable','on');
            catch %#ok<CTCH>
                fl_warning('Bad function format');
                set(findobj(ifsbdsynthesis_fig,'Tag','Button_close'),'enable','off');
                set(findobj(ifsbdsynthesis_fig,'Tag','Button_compute'),'enable','off');
            end
        end
    
    case 'popmenu_sample'
        sample_value = 2^(get(gcbo,'Value')+2);
        set(findobj(ifsbdsynthesis_fig,'Tag','EditText_sample'),'String',sample_value);

    case 'edit_sample'
        sample_value = str2num(get(gcbo,'String')); %#ok<ST2NM>
        Hldstandard = get(findobj(ifsbdsynthesis_fig,'Tag','RadioButton_standard'),'Value');
        if isempty(sample_value)
            sample_value = 2^(get(findobj(ifsbdsynthesis_fig,'Tag','PopupMenu_sample'),'Value')+2);
            set(gcbo,'String',sample_value);
        else
            sample_value = floor(trunc(sample_value,1.0,Inf));
            set(gcbo,'String',sample_value);
            if ~Hldstandard && mod(log2(sample_value),2) ~= 0 && mod(log2(sample_value),2) ~= 1
                fl_warning('Generalized option require a power of 2 sample size');
                set(gcbo,'String',2^round(log2(sample_value)));
            end
        end
        
    case 'check_law'
        if get(gcbo,'Value')
            set(gcbo,'String','Sinusoidal interpolation');
        else
            set(gcbo,'String','Affine interpolation');
        end
        
    case 'compute'
        current_cursor = fl_waiton;

        %%%%%% Disable close and compute %%%%%%%%
        set(findobj(ifsbdsynthesis_fig,'Tag','Button_close'),'enable','off');
        set(findobj(ifsbdsynthesis_fig,'Tag','Button_compute'),'enable','off');

        %%%%% Get Interoplation points, Contraction coefs and N sample %%%%%
        Minter = str2num(get(findobj(ifsbdsynthesis_fig,'Tag','EditText_point'),'String')); %#ok<ST2NM>
        Coefs = str2num(get(findobj(ifsbdsynthesis_fig,'Tag','EditText_contraction'),'String')); %#ok<ST2NM> 
        Nsamp = str2double(get(findobj(ifsbdsynthesis_fig,'Tag','EditText_sample'),'String'));
        
        %%%%% Look for option and get Holder exponent %%%%%
        Hldstandard = get(findobj(ifsbdsynthesis_fig,'Tag','RadioButton_standard'),'Value');
        if ~Hldstandard, Hfunc = get(findobj(ifsbdsynthesis_fig,'Tag','EditText_contraction'),'String'); end
        Hldsin = get(findobj(ifsbdsynthesis_fig,'Tag','Checkbox_law'),'Value');

        %%%%% Perform the computation %%%%%
        if Hldstandard
            chaine_in = ['=ifsfif(',num2str(Nsamp),',',mat2str(Minter),',',mat2str(Coefs)];
            if Hldsin
                OutputNameifsb = 'fifds';
                chaine_in = [chaine_in,',''sinusoidal'''];
            else
                OutputNameifsb = 'fifda';
                chaine_in = [chaine_in,',''affine'''];
            end
        else
            OutputNameifsb = 'fifdg';
            chaine_in = ['=ifsgfif(N,',mat2str(Minter),',Ht'];
            chaine1 = ['N=',num2str(Nsamp),'; Ht=''',Hfunc,''';'];
            eval(chaine1);
            fl_diary(chaine1);
        end
        
        varname = fl_find_mnames(varargin{2},OutputNameifsb);
        eval(['global ' varname]);
        varargout{1} = varname;
        
        chaine = [varname,chaine_in,');'];
        eval(chaine);
        
        fl_diary(chaine);
        fl_addlist(0,varname);
        fl_waitoff(current_cursor);
        fl_waitoff(current_cursor);
        
        %%%%%% Enable close and compute %%%%%%%%
        set(findobj(ifsbdsynthesis_fig,'Tag','Button_close'),'enable','on');
        set(findobj(ifsbdsynthesis_fig,'Tag','Button_compute'),'enable','on');

    case 'help'
        Hldstandard = get(findobj(ifsbdsynthesis_fig,'Tag','RadioButton_standard'),'Value');
        if Hldstandard
            fl_doc ifsfif
        else
            fl_doc ifsgfif
        end
        
    case 'close'  
        close(findobj(ifsbdsynthesis_fig,'Tag', 'Fig_gui_fl_ifsbdsynthesis'));

end
end

%--------------------------------------------------------------------------
function o=trunc(i,a,b)
if(i<a)
  o=a;
else
  if(i>b)
    o=b;
  else
    o=i;
  end 
end
end

%--------------------------------------------------------------------------
function o=comparevector(v)
n = length(v);
o = 0;
k = linspace(2,n,n-1);

for i = 1:n-1
    p = i;
    while p ~= n
        if isequal(v(i,:),v(k(p),:)), o = 1; return; end
        p = p+1;
    end
end
end