%   Continuous Wavelet Transform
%
%   This routine computes the continuous wavelet transform of a real sig-
%   nal. Two wavelets are available: the Mexican Hat or the Morlet
%   Wavelet.
%
%   1.  Usage
%
%   [wt,scales,freqs]=cwt(sig,fmin,fmax,nbscales,[wvlt_length])
%
%   1.1.  Input parameters
%
%   o  sig : real vector [1,n] or [n,1]
%      Contains the signal to be decomposed.
%
%   o  fmin : real positive scalar
%      Lowest frequency of the wavelet analysis
%
%   o  fmax : real positive scalar
%      Highest frequency of the wavelet analysis
%
%   o  nbscales : integer positive scalar
%      Number of scales to compute between the lowest and the highest
%      frequencies.
%
%   o  wvlt_length : real positive scalar (optionnal)
%      If equal to 0 or not specified, the wavelet is the Mexican Hat and
%      its length is automaticaly choosen. Otherwise, Morlet's wavelet is
%      used and it's length at scale 1 is given by wvlt_length
%
%   1.2.  Output parameters
%
%   o  wt : complex matrix [nbscales,n]
%      Wavelet transform. The first line is the finer scale ( scale 1 ).
%      It is real if the Mexican Hat has been used, complex otherwise.
%
%   o  scales : real vector [1,nbscales]
%      Scale corresponding to each line of the wavelet transform.
%
%   o  freqs : real vector [1,nbscales]
%      Frequency corresponding to each line of the wavelet transform.


% Author Bertrand Guiheneuf, February 1997

% FracLab 2.05 Beta, Copyright  1996 - 2009 by INRIA
% -- --
% For details on use and redistribution refer to $fraclab/licence.txt
%--------------------------------------------------------------------------